/* $Id: guppi-paths.h,v 1.3 2000/04/06 23:27:32 trow Exp $ */

/*
 * guppi-paths.h
 *
 * Copyright (C) 1999, 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>
 * and Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_PATHS_H
#define _INC_GUPPI_PATHS_H

#include <config.h>
#include <gnome.h>

const gchar* guppi_logo_graphic_path(void);
const gchar* guppi_glade_path(const gchar* filename);
const gchar* gnome_guile_repl_path(void);

#endif /* _INC_GUPPI_PATHS_H */

/* $Id: guppi-paths.h,v 1.3 2000/04/06 23:27:32 trow Exp $ */
